#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['funcy_chain']

package_data = \
{'': ['*']}

install_requires = \
['funcy']

extras_require = \
{'dev': ['flit >=3.3, <4'],
 'lint': ['black', 'isort', 'pylint'],
 'test': ['pytest >=2.7.3', 'tox >=3, <4']}

setup(name='funcy-chain',
      version='0.1.1',
      description='Method chaining with funcy.',
      author=None,
      author_email='Tal Einat <taleinat@gmail.com>',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
